Actions, Resources, and Condition Keys for Amazon Comprehend - AWS Identity and Access Management
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for Amazon Comprehend

Amazon Comprehend (service prefix: `comprehend` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon Comprehend
- Resource Types Defined by Amazon Comprehend
- Condition Keys for Amazon Comprehend

## Actions Defined by Amazon Comprehend

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
BatchDetectDominantLanguage | Detects the language or languages present in the list of text documents. | Read |  |  |
BatchDetectEntities | Detects the named entities ("People", "Places", "Locations", etc) within the given list of text documents. | Read |  |  |
BatchDetectKeyPhrases | Detects the phrases in the list of text documents that are most indicative of the content. | Read |  |  |
BatchDetectSentiment | Detects the sentiment of a text in the list of documents (Positive, Negative, Neutral, or Mixed). | Read |  |  |
BatchDetectSyntax | Detects syntactic information (like Part of Speech, Tokens) in a list of text documents. | Read |  |  |
ClassifyDocument | Creates a new document classification request to analyze a single document in real-time, using a previously created and trained custom model and an endpoint. | Read | document-classifier-endpoint* |  |
CreateDocumentClassifier | Creates a new document classifier that you can use to categorize documents. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateEndpoint | Creates a model-specific endpoint for synchronous inference for a previously trained custom model | Write | document-classifier |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateEntityRecognizer | Creates an entity recognizer using submitted files. | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteDocumentClassifier | Deletes a previously created document classifier. | Write | document-classifier* |  |
DeleteEndpoint | Deletes a model-specific endpoint for a previously-trained custom model. All endpoints must be deleted in order for the model to be deleted. | Write | document-classifier-endpoint* |  |
DeleteEntityRecognizer | Deletes a submitted entity recognizer. | Write | entity-recognizer* |  |
DescribeDocumentClassificationJob | Gets the properties associated with a document classification job. | Read |  |  |
DescribeDocumentClassifier | Gets the properties associated with a document classifier. | Read | document-classifier* |  |
DescribeDominantLanguageDetectionJob | Gets the properties associated with a dominant language detection job. | Read |  |  |
DescribeEndpoint | Gets the properties associated with a specific endpoint. Use this operation to get the status of an endpoint. | Read | document-classifier-endpoint* |  |
DescribeEntitiesDetectionJob | Gets the properties associated with an entities detection job. | Read |  |  |
DescribeEntityRecognizer | Provides details about an entity recognizer including status, S3 buckets containing training data, recognizer metadata, metrics, and so on. | Read | entity-recognizer* |  |
DescribeKeyPhrasesDetectionJob | Gets the properties associated with a key phrases detection job. | Read |  |  |
DescribeSentimentDetectionJob | Gets the properties associated with a sentiment detection job. | Read |  |  |
DescribeTopicsDetectionJob | Gets the properties associated with a topic detection job. | Read |  |  |
DetectDominantLanguage | Detects the language or languages present in the text. | Read |  |  |
DetectEntities | Detects the named entities ("People", "Places", "Locations", etc) within the given text document. | Read |  |  |
DetectKeyPhrases | Detects the phrases in the text that are most indicative of the content. | Read |  |  |
DetectSentiment | Detects the sentiment of a text in a document (Positive, Negative, Neutral, or Mixed). | Read |  |  |
DetectSyntax | Detects syntactic information (like Part of Speech, Tokens) in a text document. | Read |  |  |
ListDocumentClassificationJobs | Gets a list of the document classification jobs that you have submitted. | List |  |  |
ListDocumentClassifiers | Gets a list of the document classifiers that you have created. | List |  |  |
ListDominantLanguageDetectionJobs | Gets a list of the dominant language detection jobs that you have submitted. | List |  |  |
ListEndpoints | Gets a list of all existing endpoints that you've created. | List |  |  |
ListEntitiesDetectionJobs | Gets a list of the entity detection jobs that you have submitted. | List |  |  |
ListEntityRecognizers | Gets a list of the properties of all entity recognizers that you created, including recognizers currently in training. | List |  |  |
ListKeyPhrasesDetectionJobs | Get a list of key phrase detection jobs that you have submitted. | List |  |  |
ListSentimentDetectionJobs | Gets a list of sentiment detection jobs that you have submitted. | List |  |  |
ListTagsForResource | Lists tags for a resource | List | document-classifier |  |
document-classifier-endpoint |  |
entity-recognizer |  |
ListTopicsDetectionJobs | Gets a list of the topic detection jobs that you have submitted. | List |  |  |
StartDocumentClassificationJob | Starts an asynchronous document classification job. | Write | document-classifier* |  |
StartDominantLanguageDetectionJob | Starts an asynchronous dominant language detection job for a collection of documents. | Write |  |  |
StartEntitiesDetectionJob | Starts an asynchronous entity detection job for a collection of documents. | Write |  |  |
StartKeyPhrasesDetectionJob | Starts an asynchronous key phrase detection job for a collection of documents. | Write |  |  |
StartSentimentDetectionJob | Starts an asynchronous sentiment detection job for a collection of documents. | Write |  |  |
StartTopicsDetectionJob | Starts an asynchronous job to detect the most common topics in the collection of documents and the phrases associated with each topic. | Write |  |  |
StopDominantLanguageDetectionJob | Stops a dominant language detection job. | Write |  |  |
StopEntitiesDetectionJob | Stops an entity detection job. | Write |  |  |
StopKeyPhrasesDetectionJob | Stops a key phrase detection job. | Write |  |  |
StopSentimentDetectionJob | Stops a sentiment detection job. | Write |  |  |
StopTrainingDocumentClassifier | Stop a previously created document classifier training job. | Write | document-classifier* |  |
StopTrainingEntityRecognizer | Stop a previously created entity recognizer training job. | Write | entity-recognizer* |  |
TagResource | Tags a resource with given key value pairs | Tagging | document-classifier |  |
document-classifier-endpoint |  |
entity-recognizer |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Untags a resource with given key | Tagging | document-classifier |  |
document-classifier-endpoint |  |
entity-recognizer |  |
| aws:TagKeys |
UpdateEndpoint | Updates information about the specified endpoint. | Write | document-classifier-endpoint* |  |

## Resource Types Defined by Amazon Comprehend

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
document-classifier | `arn:$ { Partition}:comprehend:$ { Region}:$ { Account}:document-classifier/$ { DocumentClassifierName}` | aws:ResourceTag/${TagKey}
entity-recognizer | `arn:$ { Partition}:comprehend:$ { Region}:$ { Account}:entity-recognizer/$ { EntityRecognizerName}` | aws:ResourceTag/${TagKey}
document-classifier-endpoint | `arn:$ { Partition}:comprehend:$ { Region}:$ { Account}:document-classifier-endpoint/$ { DocumentClassifierEndpointName}` | aws:ResourceTag/${TagKey}

## Condition Keys for Amazon Comprehend

Amazon Comprehend defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/$ { TagKey} | Filters create requests based on the allowed set of values for each of the mandatory tags. | String
aws:ResourceTag/$ { TagKey} | Filters actions based on the tag value associated with the resource. | String
aws:TagKeys | Filters create requests based on the presence of mandatory tags in the request. | String